@@ -725,6 +725,7 @@ gboolean board_engine_loop (gpointer data)
 			gweled_gems_fall_off ();
 			gweled_draw_message ("time's up #");
 			gi_game_running = 0;
+			end_time = time( 0 );
 			remove(SAVE_PATH);	
 	#if 0 // gloomt		
  			hiscore_rank = gnome_score_log ((gfloat) gi_score, "timed", TRUE);
@@ -881,7 +882,7 @@ gboolean board_engine_loop (gpointer data)
 
 					gweled_gems_fall_off ();
 
-					gweled_draw_game_message ("no moves left #", 1.0);
+					gweled_draw_game_message ("no moves #", 1.0);
 					memset (gi_nb_of_tiles, 0, 7 * sizeof (gchar));
 
 					for (i = 0; i < BOARD_WIDTH; i++)
@@ -907,8 +908,9 @@ gboolean board_engine_loop (gpointer data)
 					gi_state = _MARK_ALIGNED_GEMS;
 				} else {
 					gweled_gems_fall_off ();
-					gweled_draw_message ("no moves left #");
+					gweled_draw_message ("no moves #");
 					gi_game_running = 0;
+					end_time = time(0);
 					remove(SAVE_PATH);	
 			#if 0 // gloomy		
 					hiscore_rank = gnome_score_log ((gfloat) gi_score, "easy", TRUE);
