@@ -15,6 +15,7 @@
 #endif
 
 int g_timer_mode = 1;
+int end_time = 0;
 
 SDL_mutex 	*game_mutex = NULL;
 
@@ -187,7 +188,7 @@ static int game_loop() {
 				} else if (event.button.x > BOARD_X && event.button.y > BOARD_Y &&
 					 event.button.x < (BOARD_X + BOARD_W) &&
 					 event.button.y < (BOARD_Y + BOARD_H) &&
-					!gi_game_running)
+					!gi_game_running && time(0) > end_time + 3 )
 					gweled_start_new_game(1);
 				else if ( event.button.x > RESTART_X && event.button.y > RESTART_Y && 
 					event.button.x < (RESTART_X + RESTART_W) && 
